==> Acme-CPANLists-PERLANCAR-Temp-Plus-0.001.tar.gz: Acme-CPANLists-PERLANCAR-Temp-Plus-0.001/lib/Acme/CPANLists/PERLANCAR/Temp/Plus.pm <==
package Acme::CPANLists::PERLANCAR::Temp::Plus;

our $DATE = '2016-12-21'; # DATE
our $VERSION = '0.001'; # VERSION

our @Module_Lists = (
    {
        summary => "Modules I plus while MetaCPAN's ++ is not working",
        entries => [
            {module => 'App::Trrr', date=>'2016-12-15'},
            {module => 'App::squaretag', date=>'2016-12-15'},
            {module => 'App::Wax', date=>'2016-12-21'},
        ],
    },
);

1;
# ABSTRACT: Modules I plus while MetaCPAN's ++ is not working

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANLists::PERLANCAR::Temp::Plus - Modules I plus while MetaCPAN's ++ is not working

=head1 VERSION

This document describes version 0.001 of Acme::CPANLists::PERLANCAR::Temp::Plus (from Perl distribution Acme-CPANLists-PERLANCAR-Temp-Plus), released on 2016-12-21.

=head1 MODULE LISTS

=head2 Modules I plus while MetaCPAN's ++ is not working

=over

=item * L<App::Trrr>

=item * L<App::squaretag>

=item * L<App::Wax>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANLists-PERLANCAR-Temp-Plus>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANLists-PERLANCAR-Temp-Plusses>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANLists-PERLANCAR-Temp-Plus>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANLists> - about the Acme::CPANLists namespace

L<acme-cpanlists> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Acme-CPANLists-PERLANCAR-Temp-Plus-0.002.tar.gz: Acme-CPANLists-PERLANCAR-Temp-Plus-0.002/lib/Acme/CPANLists/PERLANCAR/Temp/Plus.pm <==
package Acme::CPANLists::PERLANCAR::Temp::Plus;

our $DATE = '2017-02-05'; # DATE
our $VERSION = '0.002'; # VERSION

our @Module_Lists = (
    {
        summary => "Modules I plus while MetaCPAN's ++ is not working",
        entries => [
            {module => 'App::Trrr', date=>'2016-12-15'},
            {module => 'App::Wax', date=>'2016-12-21'},
            {module => 'App::cpangrep', date=>'2016-12-25'},
            {module => 'Acme::PPIx::MetaSyntactic', date=>'2017-02-04'},
        ],
    },
);

1;
# ABSTRACT: Modules I plus while MetaCPAN's ++ is not working

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANLists::PERLANCAR::Temp::Plus - Modules I plus while MetaCPAN's ++ is not working

=head1 VERSION

This document describes version 0.002 of Acme::CPANLists::PERLANCAR::Temp::Plus (from Perl distribution Acme-CPANLists-PERLANCAR-Temp-Plus), released on 2017-02-05.

=head1 MODULE LISTS

=head2 Modules I plus while MetaCPAN's ++ is not working

=over

=item * L<App::Trrr>

=item * L<App::Wax>

=item * L<App::cpangrep>

=item * L<Acme::PPIx::MetaSyntactic>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANLists-PERLANCAR-Temp-Plus>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANLists-PERLANCAR-Temp-Plusses>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANLists-PERLANCAR-Temp-Plus>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANLists> - about the Acme::CPANLists namespace

L<acme-cpanlists> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
